@@ -1,5 +1,12 @@
 use crate::core::prelude::*;
 
+pub fn map_signal_type_to_lattice_string(k: &SignalType) -> &str {
+    match k {
+        SignalType::LowVoltageCMOS_3v3 => "LVCMOS33",
+        _ => panic!("Unsupported mapping for signal type {:?} in Lattice mapping", k),
+    }
+}
+
 pub fn map_signal_type_to_xilinx_string(k: &SignalType) -> &str {
     match k {
         SignalType::LowVoltageCMOS_1v8 => "LVCMOS18",
@@ -21,3 +28,4 @@ pub fn map_signal_type_to_xilinx_string(k: &SignalType) -> &str {
 pub mod icestorm;
 pub mod ise;
 pub mod vivado;
+pub mod ecp5;
